NAME
Mail::SpamAssassin::Plugin::ARC - perform ARC verification tests
SYNOPSIS
loadplugin Mail::SpamAssassin::Plugin::ARC [/path/to/ARC.pm]
full ARC_SIGNED eval:check_arc_signed()
full ARC_VALID eval:check_arc_valid()
full ARC_TRUSTED eval:check_arc_trusted()
DESCRIPTION
This SpamAssassin plugin implements ARC (Authenticated Received Chain) verification as described by RFC 8617.
If the AuthRes plugin is loaded and has parsed arc= results from Authentication-Results headers, those results will be re-used and native verification is skipped. Otherwise, the plugin performs its own cryptographic verification using the Mail::DKIM::ARC::Verifier module (version 0.50 or later required).
SEE ALSO
Mail::DKIM Mail::SpamAssassin::Plugin(3)
https://www.rfc-editor.org/rfc/rfc8617
USER SETTINGS
- arc_timeout n (default: 5)
-
Timeout in seconds for ARC signature verification. If Mail::DKIM cannot complete verification within this time, the ARC check will be aborted.
- arc_trusted_sealers domain1 domain2 ...
-
Specify domains that are trusted as ARC sealers. When the ARC chain is cryptographically valid, the plugin will parse ARC-Authentication-Results headers from trusted sealers and make them available to other plugins (such as DMARC) via
$pms->{arc_auth_results}. ARC instances sealed by untrusted domains are ignored.If no trusted sealers are configured, ARC-Authentication-Results headers will not be parsed.
Can be specified multiple times, additional entries are appended.
arc_trusted_sealers google.com microsoft.com arc_trusted_sealers yahoo.com